grasia-dash-components is a third party extension of the [Dash](https://pypi.org/project/dash/)
components suite. It adds new components or extends the default ones.

This is a list of the currently available components:
* Accordion: A list of items that can be collapsed (folded) or un-collapsed (unfolded).
* Card: A component for framing content that can contain an image, text, etcetera.
* Import: A component to import external javascript libraries into your web app.
* LoadingDialog: A loading Dialog/Popup.
* Tabs: An extension of the [[WIP] Dash component](https://github.com/plotly/dash-core-components/pull/74) that supports embbebing icons in the tabs as well as other improvements.

To use it, simply install it from pip: `pip install grasia-dash-components`
and import it with `import grasia_dash_components`.

We use this suite for our projects.
 But we have this suite [open-sourced](https://github.com/Grasia/grasia-dash-components)
 and we try to keep it well maintained.
